#!/bin/sh
# usr/opt/wrdapp/airslug1.1/test/test.sh -- run airslug test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          03/08/96, rsregan, modified for use with airslug
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  PROGNM=airslug
  PROG=$TOPDIR/bin/$PROGNM
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  DATA=$TOPDIR/data
  END=5
  DIVD=========================================

#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                             # by default, stop at 5
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    if [ $Start -gt $END ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# remove old output file
  $CLEAN

#
# begin test runs
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi

  drdelt=`expr $Test + 3`
  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    Name=$PROGNM$Test
    rm -f go 
    echo "0.$drdelt" > go
    echo $Name.out >> go
    if [ $Test -eq 1 ] 
    then
      echo "1" >> go
      echo "0.0001" >> go
    elif [ $Test -eq 2 ] 
    then
      echo "1" >> go
      echo "0.000001" >> go
    else
      echo "0" >> go
    fi
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    $PROG < go > $Name.log
    Test=`expr $Test + 1`
    drdelt=`expr $drdelt + 1`
  done
  Test=`expr $Test - 1`
#
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Test"
    echo
  fi

# check output against original output in $DATA directory
  $CHECK $PROGNM
